#ifndef __COLOR_H_
#define __COLOR_H_

enum {
    FIELD_NOT_MATCH=0,
    FIELD_MATCH
};

enum {
    CONF_COMMENT=0,
    CONF_COLOR1_FORE,
    CONF_COLOR1_BG,
    CONF_COLOR2_FORE,
    CONF_COLOR2_BG,
    CONF_COLOR3_FORE,
    CONF_COLOR3_BG,
    CONF_COLOR4_FORE,
    CONF_COLOR4_BG,
    CONF_COLOR5_FORE,
    CONF_COLOR5_BG,
    CONF_COLOR6_FORE,
    CONF_COLOR6_BG,
    CONF_COLOR7_FORE,
    CONF_COLOR7_BG,
    CONF_COLOR8_FORE,
    CONF_COLOR8_BG,
    CONF_COLOR9_FORE,
    CONF_COLOR9_BG,
    CONF_COLOR10_FORE,
    CONF_COLOR10_BG
};

void init_curses_colors(void);

#endif
